Learn R Programming

ActiSleep (version 0.2.2)

SleepDiary1Day: Sleep Diary 1-Day Data

Description

A small dataset containing sleep diary data for a single day and single subject

  • bed. time at which the subject reported going to sleep on day 1

  • wake. time at which the subject reported waking up on day 1

Usage

data("SleepDiary1Day")

Arguments

Format

a data frame with 1 row and 2 variables